@@ -1,4 +1,4 @@
-__version_info__ = (2, 0, 8)
+__version_info__ = (2, 1, 2)
 __version__ = '.'.join(map(str, __version_info__))
 __maintainer__ = 'Jeroen van der Heijden'
-__email__ = 'jeroen@transceptor.technology'
+__email__ = 'jeroen@cesbit.com'
