@@ -5,7 +5,7 @@ from .lib.protocol import _SiriDBProtocol
 from .lib.protocol import _SiriDBInfoProtocol
 from .lib.connection import SiriDBConnection
 from .lib.defaults import DEFAULT_CLIENT_PORT
-from .lib.client import SiriDBClient
+from .lib.client import SiriDBClient, SiriDBConn
 from .lib.constants import SECOND
 from .lib.constants import MICROSECOND
 from .lib.constants import MILLISECOND
